EXPORTS
	??0CSchSendTestUtils@@IAE@AAVRTest@@@Z @ 1 NONAME ; protected: __thiscall CSchSendTestUtils::CSchSendTestUtils(class RTest &)
	??1CSchSendTestUtils@@MAE@XZ @ 2 NONAME ; protected: virtual __thiscall CSchSendTestUtils::~CSchSendTestUtils(void)
	??1CScheduleTestActive@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CScheduleTestActive::~CScheduleTestActive(void)
	??6@YAAAVRTest@@AAV0@VTTime@@@Z @ 4 NONAME ; class RTest & __cdecl operator<<(class RTest &,class TTime)
	??8@YAHABVCMsvScheduleSettings@@0@Z @ 5 NONAME ; int __cdecl operator==(class CMsvScheduleSettings const &,class CMsvScheduleSettings const &)
	??8@YAHABVCMsvSendErrorActions@@0@Z @ 6 NONAME ; int __cdecl operator==(class CMsvSendErrorActions const &,class CMsvSendErrorActions const &)
	??8@YAHABVTMsvOffPeakTime@@0@Z @ 7 NONAME ; int __cdecl operator==(class TMsvOffPeakTime const &,class TMsvOffPeakTime const &)
	??8@YAHABVTMsvSendErrorAction@@0@Z @ 8 NONAME ; int __cdecl operator==(class TMsvSendErrorAction const &,class TMsvSendErrorAction const &)
	?AssertL@CSchSendTestUtils@@IAEXH@Z @ 9 NONAME ; protected: void __thiscall CSchSendTestUtils::AssertL(int)
	?ChangeMessageTimeL@CSchSendTestUtils@@IAEXJVTTime@@@Z @ 10 NONAME ; protected: void __thiscall CSchSendTestUtils::ChangeMessageTimeL(long,class TTime)
	?CleanScheduleFolderL@CSchSendTestUtils@@IAEXXZ @ 11 NONAME ; protected: void __thiscall CSchSendTestUtils::CleanScheduleFolderL(void)
	?CompareRoundedTimes@CSchSendTestUtils@@IBEHABVTTime@@0@Z @ 12 NONAME ; protected: int __thiscall CSchSendTestUtils::CompareRoundedTimes(class TTime const &,class TTime const &)const 
	?ConstructL@CSchSendTestUtils@@MAEXXZ @ 13 NONAME ; protected: virtual void __thiscall CSchSendTestUtils::ConstructL(void)
	?CreateMessageLC@CSchSendTestUtils@@IAEJAAVTMsvEntry@@JVTTime@@H@Z @ 14 NONAME ; protected: long __thiscall CSchSendTestUtils::CreateMessageLC(class TMsvEntry &,long,class TTime,int)
	?CreateServerMtmRegsL@CSchSendTestUtils@@MAEXXZ @ 15 NONAME ; protected: virtual void __thiscall CSchSendTestUtils::CreateServerMtmRegsL(void)
	?DiffInMins@CSchSendTestUtils@@IAEHVTTime@@0@Z @ 16 NONAME ; protected: int __thiscall CSchSendTestUtils::DiffInMins(class TTime,class TTime)
	?DiffInSecs@CSchSendTestUtils@@IAEHVTTime@@0@Z @ 17 NONAME ; protected: int __thiscall CSchSendTestUtils::DiffInSecs(class TTime,class TTime)
	?DisplayAllSchedulesL@CSchSendTestUtils@@IAEXAAH0@Z @ 18 NONAME ; protected: void __thiscall CSchSendTestUtils::DisplayAllSchedulesL(int &,int &)
	?InstallMtmGroupsL@CSchSendTestUtils@@MAEXXZ @ 19 NONAME ; protected: virtual void __thiscall CSchSendTestUtils::InstallMtmGroupsL(void)
	?NewL@CSchSendTestTimer@@SAPAV1@H@Z @ 20 NONAME ; public: static class CSchSendTestTimer * __cdecl CSchSendTestTimer::NewL(int)
	?NewL@CScheduleTestActive@@SAPAV1@AAVCSchSendTestUtils@@H@Z @ 21 NONAME ; public: static class CScheduleTestActive * __cdecl CScheduleTestActive::NewL(class CSchSendTestUtils &,int)
	?Panic@CSchSendTestUtils@@MAEXH@Z @ 22 NONAME ; protected: virtual void __thiscall CSchSendTestUtils::Panic(int)
	?RoundDownToMinute@CSchSendTestUtils@@IBE?AVTTime@@ABV2@@Z @ 23 NONAME ; protected: class TTime  __thiscall CSchSendTestUtils::RoundDownToMinute(class TTime const &)const 
	?RoundUpToMinute@CSchSendTestUtils@@IBE?AVTTime@@ABV2@@Z @ 24 NONAME ; protected: class TTime  __thiscall CSchSendTestUtils::RoundUpToMinute(class TTime const &)const 
	?StartL@CSchSendTestUtils@@QAEXXZ @ 25 NONAME ; public: void __thiscall CSchSendTestUtils::StartL(void)
	?StartsAt@@YAHABVTMsvOffPeakTime@@ABVTTime@@@Z @ 26 NONAME ; int __cdecl StartsAt(class TMsvOffPeakTime const &,class TTime const &)
	?TransferCommandSyncL@CScheduleTestActive@@QAEABVTSchSendTestProgress@@W4TSchSendTestOperation@@ABVCMsvEntrySelection@@H@Z @ 27 NONAME ; public: class TSchSendTestProgress const & __thiscall CScheduleTestActive::TransferCommandSyncL(enum TSchSendTestOperation,class CMsvEntrySelection const &,int)
	??1CSchSendTestWaitForState@@UAE@XZ @ 28 NONAME ; public: virtual __thiscall CSchSendTestWaitForState::~CSchSendTestWaitForState(void)
	?NewL@CSchSendTestWaitForState@@SAPAV1@AAVCSchSendTestUtils@@@Z @ 29 NONAME ; public: static class CSchSendTestWaitForState * __cdecl CSchSendTestWaitForState::NewL(class CSchSendTestUtils &)
	?StartL@CSchSendTestWaitForState@@QAEXABVCMsvEntrySelection@@@Z @ 30 NONAME ; public: void __thiscall CSchSendTestWaitForState::StartL(class CMsvEntrySelection const &)
	?StartL@CSchSendTestWaitForState@@QAEXABVCMsvEntrySelection@@VTTimeIntervalMicroSeconds32@@@Z @ 31 NONAME ; public: void __thiscall CSchSendTestWaitForState::StartL(class CMsvEntrySelection const &,class TTimeIntervalMicroSeconds32)
	?Reset@CSchSendTestWaitForState@@QAEXXZ @ 32 NONAME ; public: void __thiscall CSchSendTestWaitForState::Reset(void)
	?TransferCommandSyncL@CScheduleTestActive@@QAEABVTSchSendTestProgress@@W4TSchSendTestOperation@@ABVCMsvEntrySelection@@ABVTDesC8@@H@Z @ 33 NONAME ; public: class TSchSendTestProgress const & __thiscall CScheduleTestActive::TransferCommandSyncL(enum TSchSendTestOperation,class CMsvEntrySelection const &,class TDesC8 const &,int)
	??8@YAHABVTMsvSchedulePackage@@0@Z @ 34 NONAME ; int __cdecl operator==(class TMsvSchedulePackage const &,class TMsvSchedulePackage const &)

